@@ -19,8 +19,11 @@ import os
 import wave
 import numpy as np
 from ctypes import  *
+from SNR_ESTIMATION.MATCH_SIG import match_sig
+from SNR_ESTIMATION.SNR_MUSIC import cal_snr_music
+from SNR_ESTIMATION.SNR_TRANSIENT import cal_snr_transient
 
-allMetrics = ['G160','P563','POLQA','PESQ','STOI','STI','PEAQ','SDR','SII','LOUDNESS']
+allMetrics = ['G160','P563','POLQA','PESQ','STOI','STI','PEAQ','SDR','SII','LOUDNESS','MUSIC','TRANSIENT','MATCH']
 
 
 class computeAudioQuality():
@@ -42,6 +45,8 @@ class computeAudioQuality():
         self.testFile = kwargs['testFile']
         self.refFile = kwargs['refFile']
         self.cleFile = kwargs['cleFile']
+        self.noiseFile = kwargs['noiseFile']
+        self.outFile = kwargs['outFile']
         self.samplerate = kwargs['samplerate']
         self.bitwidth = kwargs['bitwidth']
         self.channel = kwargs['channel']
@@ -86,13 +91,13 @@ class computeAudioQuality():
         if self.__check_format(self.testFile) != self.__check_format(self.refFile):
             raise TypeError('there are different parametre in inputfiles!')
 
-    def __data_convert(self):
+    def __data_convert(self,ref,test):
         """
         :return:
         """
-        with open(wav2pcm(self.refFile), 'rb') as ref:
+        with open(wav2pcm(ref), 'rb') as ref:
             pcmdata = ref.read()
-        with open(wav2pcm(self.testFile), 'rb') as ref:
+        with open(wav2pcm(test), 'rb') as ref:
             indata = ref.read()
         ref = np.frombuffer(pcmdata, dtype=np.int16)
         ins = np.frombuffer(indata, dtype=np.int16)
@@ -173,13 +178,12 @@ class computeAudioQuality():
         """
         #STOI
         #数据块输入
-        #采样率无关
+        #采样率 16000
         :return:
         """
         self.__double_end_check()
-        self.refFile,self.testFile = wav2pcm(self.refFile),wav2pcm(self.testFile)
-        ref, ins = self.__data_convert()
-        result = cal_stoi(ref,ins,sr=self.samplerate)
+        ref, ins = self.__data_convert(wav2pcm(resample(pcm2wav(self.refFile),16000)),wav2pcm(resample(pcm2wav(self.testFile),16000)))
+        result = cal_stoi(ref,ins,sr=16000)
         print(result)
         return result
         pass
@@ -215,13 +219,48 @@ class computeAudioQuality():
         :return:
         """
         self.__double_end_check()
-        self.refFile,self.testFile = wav2pcm(self.refFile),wav2pcm(self.testFile)
-        ref,ins = self.__data_convert()
-        result = cal_sdr(ref,ins)
+        ref, ins = self.__data_convert(wav2pcm(resample(pcm2wav(self.refFile),16000)),wav2pcm(resample(pcm2wav(self.testFile),16000)))
+        result = cal_stoi(ref,ins,sr=16000)
         print(result)
         return result
         pass
 
+    def MUSIC(self):
+        """
+        # MUSIC SNR
+        # 无采样率限制
+        # WAV/PCM 输入
+        :return:
+        """
+        self.__double_end_check()
+        print(self.refFile,self.testFile)
+        return cal_snr_music(refFile=pcm2wav(self.refFile,sample_rate=self.samplerate),testFile=pcm2wav(self.testFile,sample_rate=self.samplerate))
+
+    def TRANSIENT(self):
+        """
+        # Transient noise SNR
+        # 无采样率限制
+        # WAV/PCM 输入
+        :return:
+        """
+        if self.cleFile is None or self.testFile is None or self.noiseFile is None:
+            raise EOFError('lack of inputfiles!')
+        if self.__check_format(self.cleFile) != self.__check_format(self.testFile) or \
+            self.__check_format(self.testFile) != self.__check_format(self.noiseFile):
+            raise TypeError('there are different parametre in inputfiles!')
+        return cal_snr_transient(pcm2wav(self.cleFile,sample_rate=self.samplerate),pcm2wav(self.noiseFile,sample_rate=self.samplerate),pcm2wav(self.testFile,sample_rate=self.samplerate))
+
+    def MATCH(self):
+        """
+        # MATCH SIG
+        # 无采样率限制
+        # 可选择是否输出文件
+        # WAV/PCM 输入
+        :return:
+        """
+        self.__double_end_check()
+        return match_sig(pcm2wav(self.refFile,sample_rate=self.samplerate), pcm2wav(self.testFile,sample_rate=self.samplerate), self.outFile)
+
     def LOUDNESS(self):
         pass
 
